receiver_country
================

The receiver country refers to the country targeted by the cyber incident.

The following receiver countries can be queried in the database, **use the country's full name, as spelt below**.
Leaving the filter to its default value (None) will return all receiver countries.

* Afghanistan
* Africa
* Albania
* Algeria
* American Samoa
* Andorra
* Angola
* Anguilla
* Antarctica
* Antigua and Barbuda
* Argentina
* Armenia
* Aruba
* Australia
* Austria
* Azerbaijan
* Bahamas
* Bahrain
* Bangladesh
* Barbados
* Belarus
* Belgium
* Belize
* Benin
* Bermuda
* Bhutan
* Bolivia
* Bosnia and Herzegovina
* Botswana
* Bouvet Island
* Brazil
* British Indian Ocean Territory
* Brunei
* Bulgaria
* Burkina Faso
* Burundi
* Cambodia
* Cameroon
* Canada
* Cape Verde
* Caucasus
* Cayman Islands
* Central African Republic
* Chad
* Chile
* China
* Christmas Island
* Cocos (Keeling) Islands
* Colombia
* Comoros
* Congo
* Congo, the Democratic Republic of the
* Cook Islands
* Costa Rica
* Croatia
* Cuba
* Cyprus
* Czech Republic
* Denmark
* Djibouti
* Dominica
* Dominican Republic
* Ecuador
* Egypt
* El Salvador
* Equatorial Guinea
* Eritrea
* Estonia
* Ethiopia
* European Space Agency
* Falkland Islands (Malvinas)
* Faroe Islands
* Fiji
* Finland
* France
* French Guiana
* French Polynesia
* French Southern Territories
* Gabon
* Gambia
* Georgia
* Germany
* Ghana
* Gibraltar
* Greece
* Greenland
* Grenada
* Guadeloupe
* Guam
* Guatemala
* Guernsey
* Guinea
* Guinea-Bissau
* Guyana
* Haiti
* Heard Island and McDonald Islands
* Holy See (Vatican City State)
* Honduras
* Hong Kong
* Hungary
* Iceland
* India
* Indonesia
* International Association of Athletics Federations
* International Atomic Energy Agency
* International Monetary Fund
* Interpol
* Iran, Islamic Republic of
* Iraq
* Ireland
* ISIS
* Isle of Man
* Israel
* Italy
* Ivory Coast
* Jamaica
* Japan
* Jersey
* Jordan
* Kazakhstan
* Kenya
* Kiribati
* Korea, Democratic People's Republic of
* Korea, Republic of
* Kosovo
* Kuwait
* Kyrgyzstan
* Laos
* Latvia
* Lebanon
* Lesotho
* Liberia
* Libya
* Liechtenstein
* Lithuania
* Luxembourg
* Macao
* Madagascar
* Malawi
* Malaysia
* Maldives
* Mali
* Malta
* Marshall Islands
* Martinique
* Mauritania
* Mauritius
* Mayotte
* Mexico
* Micronesia, Federated States of
* Moldova, Republic of
* Monaco
* Mongolia
* Montenegro
* Montserrat
* Morocco
* Mozambique
* Myanmar
* Namibia
* Nauru
* Nepal
* Netherlands
* New Caledonia
* New Zealand
* Nicaragua
* Niger
* Nigeria
* Niue
* Norfolk Island
* North America
* North Macedonia
* Northern Europe
* Northern Mariana Islands
* Norway
* Not available
* Oman
* Organization for Security and Cooperation in Europe
* Organization for the Prohibition of Chemical Weapons
* Pakistan
* Palau
* Palestine
* Panama
* Papua New Guinea
* Paraguay
* Peru
* Philippines
* Pitcairn
* Poland
* Portugal
* Puerto Rico
* Qatar
* Réunion
* Romania
* Russia
* Rwanda
* Samoa
* San Marino
* Sao Tome and Principe
* Saudi Arabia
* Senegal
* Serbia
* Seychelles
* Sierra Leone
* Singapore
* Slovakia
* Slovenia
* Solomon Islands
* Somalia
* South Africa
* South Georgia and the South Sandwich Islands
* South Sudan
* Spain
* Sri Lanka
* St. Helena, Ascension and Tristan da Cunha
* St. Kitts and Nevis
* St. Lucia
* St. Pierre and Miquelon
* St. Vincent and the Grenadines
* Sudan
* Suriname
* Svalbard and Jan Mayen
* Swaziland
* Sweden
* Switzerland
* Syria
* Taiwan
* Tajikistan
* Tanzania
* Thailand
* Timor-Leste
* Togo
* Tokelau
* Tonga
* Trinidad and Tobago
* Tunisia
* Turkey
* Turkmenistan
* Turks and Caicos Islands
* Tuvalu
* Uganda
* Ukraine
* UNICEF
* United Arab Emirates
* United Kingdom
* United Nations
* United Nations Economic and Social Council
* United Nations Environment Programme
* United Nations Organization
* United States
* Unknown
* Uruguay
* Uzbekistan
* Vanuatu
* Venezuela
* Vietnam
* Virgin Islands, British
* Virgin Islands, U.S.
* Wallis and Futuna
* Western Sahara
* World Anti-Doping Agency
* World Trade Organization
* Yemen
* Zambia
* Zimbabwe
